@@ -13,13 +13,14 @@ If you want a model for developing a new IO start from exampleIO.
 """
 
 import collections
+import logging
 
-from neo.core import (AnalogSignal, AnalogSignalArray, Block,
-                      Epoch, EpochArray, Event, EventArray,
+from neo import logging_handler
+from neo.core import (AnalogSignal, Block,
+                      Epoch, Event,
                       IrregularlySampledSignal,
-                      RecordingChannel, RecordingChannelGroup,
-                      Segment, Spike, SpikeTrain, Unit)
-from neo.io.tools import create_many_to_one_relationship
+                      ChannelIndex,
+                      Segment, SpikeTrain, Unit)
 
 read_error = "This type is not supported by this file format for reading"
 write_error = "This type is not supported by this file format for writing"
@@ -36,11 +37,11 @@ class BaseIO(object):
     The key methods of the class are:
         - ``read()`` - Read the whole object structure, return a list of Block
                 objects
-        - ``read_block(lazy=True, cascade=True, **params)`` - Read Block object
+        - ``read_block(lazy=True, **params)`` - Read Block object
                 from file with some parameters
-        - ``read_segment(lazy=True, cascade=True, **params)`` - Read Segment
+        - ``read_segment(lazy=True, **params)`` - Read Segment
                 object from file with some parameters
-        - ``read_spiketrainlist(lazy=True, cascade=True, **params)`` - Read
+        - ``read_spiketrainlist(lazy=True, **params)`` - Read
                 SpikeTrainList object from file with some parameters
         - ``write()`` - Write the whole object structure
         - ``write_block(**params)``    - Write Block object to file with some
@@ -51,7 +52,7 @@ class BaseIO(object):
                 file with some parameters
 
     The class can also implement these methods:
-        - ``read_XXX(lazy=True, cascade=True, **params)``
+        - ``read_XXX(lazy=True, **params)``
         - ``write_XXX(**params)``
         where XXX could be one of the objects supported by the IO
 
@@ -60,9 +61,9 @@ class BaseIO(object):
     The object types can be one of the classes defined in neo.core
     (Block, Segment, AnalogSignal, ...)
 
-    Each class do not necessary support all the whole neo hierarchy but part
+    Each class does not necessary support all the whole neo hierarchy but part
     of it.
-    This is discribe with **supported_objects**.
+    This is described with **supported_objects**.
     All IOs must support at least Block with a read_block()
 
 
@@ -80,35 +81,45 @@ class BaseIO(object):
     readable_objects = []
     writeable_objects = []
 
-    has_header = False
-    is_streameable = False
+    support_lazy = False
+
     read_params = {}
     write_params = {}
 
     name = 'BaseIO'
-    description = 'This IO does not read or write anything'
-    extentions = []
+    description = ''
+    extensions = []
 
     mode = 'file'  # or 'fake' or 'dir' or 'database'
 
     def __init__(self, filename=None, **kargs):
         self.filename = filename
+        # create a logger for the IO class
+        fullname = self.__class__.__module__ + '.' + self.__class__.__name__
+        self.logger = logging.getLogger(fullname)
+        # create a logger for 'neo' and add a handler to it if it doesn't
+        # have one already.
+        # (it will also not add one if the root logger has a handler)
+        corename = self.__class__.__module__.split('.')[0]
+        corelogger = logging.getLogger(corename)
+        rootlogger = logging.getLogger()
+        if not corelogger.handlers and not rootlogger.handlers:
+            corelogger.addHandler(logging_handler)
 
     ######## General read/write methods #######################
-    def read(self, lazy=False, cascade=True,  **kargs):
+    def read(self, lazy=False, **kargs):
+        if lazy:
+            assert self.support_lazy, 'This IO do not support lazy loading'
         if Block in self.readable_objects:
             if (hasattr(self, 'read_all_blocks') and
                     callable(getattr(self, 'read_all_blocks'))):
-                return self.read_all_blocks(lazy=lazy, cascade=cascade,
-                                            **kargs)
-            return [self.read_block(lazy=lazy, cascade=cascade, **kargs)]
+                return self.read_all_blocks(lazy=lazy, **kargs)
+            return [self.read_block(lazy=lazy, **kargs)]
         elif Segment in self.readable_objects:
             bl = Block(name='One segment only')
-            if not cascade:
-                return bl
-            seg = self.read_segment(lazy=lazy, cascade=cascade,  **kargs)
+            seg = self.read_segment(lazy=lazy, **kargs)
             bl.segments.append(seg)
-            create_many_to_one_relationship(bl)
+            bl.create_many_to_one_relationship()
             return [bl]
         else:
             raise NotImplementedError
@@ -132,86 +143,56 @@ class BaseIO(object):
 
     ######## All individual read methods #######################
     def read_block(self, **kargs):
-        assert(Block in self.readable_objects), read_error
+        assert (Block in self.readable_objects), read_error
 
     def read_segment(self, **kargs):
-        assert(Segment in self.readable_objects), read_error
+        assert (Segment in self.readable_objects), read_error
 
     def read_unit(self, **kargs):
-        assert(Unit in self.readable_objects), read_error
+        assert (Unit in self.readable_objects), read_error
 
     def read_spiketrain(self, **kargs):
-        assert(SpikeTrain in self.readable_objects), read_error
-
-    def read_spike(self, **kargs):
-        assert(Spike in self.readable_objects), read_error
+        assert (SpikeTrain in self.readable_objects), read_error
 
     def read_analogsignal(self, **kargs):
-        assert(AnalogSignal in self.readable_objects), read_error
+        assert (AnalogSignal in self.readable_objects), read_error
 
     def read_irregularlysampledsignal(self, **kargs):
-        assert(IrregularlySampledSignal in self.readable_objects), read_error
+        assert (IrregularlySampledSignal in self.readable_objects), read_error
 
-    def read_analogsignalarray(self, **kargs):
-        assert(AnalogSignalArray in self.readable_objects), read_error
-
-    def read_recordingchannelgroup(self, **kargs):
-        assert(RecordingChannelGroup in self.readable_objects), read_error
-
-    def read_recordingchannel(self, **kargs):
-        assert(RecordingChannel in self.readable_objects), read_error
+    def read_channelindex(self, **kargs):
+        assert (ChannelIndex in self.readable_objects), read_error
 
     def read_event(self, **kargs):
-        assert(Event in self.readable_objects), read_error
-
-    def read_eventarray(self, **kargs):
-        assert(EventArray in self.readable_objects), read_error
+        assert (Event in self.readable_objects), read_error
 
     def read_epoch(self, **kargs):
-        assert(Epoch in self.readable_objects), read_error
-
-    def read_epocharray(self, **kargs):
-        assert(EpochArray in self.readable_objects), read_error
+        assert (Epoch in self.readable_objects), read_error
 
     ######## All individual write methods #######################
     def write_block(self, bl, **kargs):
-        assert(Block in self.writeable_objects), write_error
+        assert (Block in self.writeable_objects), write_error
 
     def write_segment(self, seg, **kargs):
-        assert(Segment in self.writeable_objects), write_error
+        assert (Segment in self.writeable_objects), write_error
 
     def write_unit(self, ut, **kargs):
-        assert(Unit in self.writeable_objects), write_error
+        assert (Unit in self.writeable_objects), write_error
 
     def write_spiketrain(self, sptr, **kargs):
-        assert(SpikeTrain in self.writeable_objects), write_error
+        assert (SpikeTrain in self.writeable_objects), write_error
 
-    def write_spike(self, sp, **kargs):
-        assert(Spike in self.writeable_objects), write_error
-
-    def write_analogsignal(self, anasig,  **kargs):
-        assert(AnalogSignal in self.writeable_objects), write_error
+    def write_analogsignal(self, anasig, **kargs):
+        assert (AnalogSignal in self.writeable_objects), write_error
 
     def write_irregularlysampledsignal(self, irsig, **kargs):
-        assert(IrregularlySampledSignal in self.writeable_objects), write_error
+        assert (IrregularlySampledSignal in self.writeable_objects), write_error
 
-    def write_analogsignalarray(self, anasigar, **kargs):
-        assert(AnalogSignalArray in self.writeable_objects), write_error
-
-    def write_recordingchannelgroup(self, rcg, **kargs):
-        assert(RecordingChannelGroup in self.writeable_objects), write_error
-
-    def write_recordingchannel(self, rc, **kargs):
-        assert(RecordingChannel in self.writeable_objects), write_error
+    def write_channelindex(self, chx, **kargs):
+        assert (ChannelIndex in self.writeable_objects), write_error
 
     def write_event(self, ev, **kargs):
-        assert(Event in self.writeable_objects), write_error
-
-    def write_eventarray(self, ea,  **kargs):
-        assert(EventArray in self.writeable_objects), write_error
+        assert (Event in self.writeable_objects), write_error
 
     def write_epoch(self, ep, **kargs):
-        assert(Epoch in self.writeable_objects), write_error
-
-    def write_epocharray(self, epa,  **kargs):
-        assert(EpochArray in self.writeable_objects), write_error
+        assert (Epoch in self.writeable_objects), write_error
