@@ -21,6 +21,7 @@ import shutil
 
 # note neo.core need only numpy and quantitie
 import numpy as np
+
 try:
     import matplotlib.mlab as mlab
 except ImportError as err:
@@ -30,12 +31,10 @@ else:
     HAVE_MLAB = True
     MLAB_ERR = None
 
-
 # I need to subclass BaseIO
 from neo.io.baseio import BaseIO
 
 from neo.core import Block, Segment, Unit, SpikeTrain
-from neo.io.tools import create_many_to_one_relationship
 
 # Pasted version of feature file format spec
 """
@@ -53,10 +52,10 @@ Assuming N1 spikes (spike1...spikeN1), N2 electrodes (e1...eN2) and
 N3 coefficients (c1...cN3), this file looks like:
 
 nbDimensions
-c1_e1_spike1   c2_e1_spike1  ... cN3_e1_spike1   c1_e2_spike1  ... cN3_eN2_spike1   timestamp_spike1
-c1_e1_spike2   c2_e1_spike2  ... cN3_e1_spike2   c1_e2_spike2  ... cN3_eN2_spike2   timestamp_spike2
+c1_e1_spk1   c2_e1_spk1  ... cN3_e1_spk1   c1_e2_spk1  ... cN3_eN2_spk1   timestamp_spk1
+c1_e1_spk2   c2_e1_spk2  ... cN3_e1_spk2   c1_e2_spk2  ... cN3_eN2_spk2   timestamp_spk2
 ...
-c1_e1_spikeN1  c2_e1_spikeN1 ... cN3_e1_spikeN1  c1_e2_spikeN1 ... cN3_eN2_spikeN1  timestamp_spikeN1
+c1_e1_spkN1  c2_e1_spkN1 ... cN3_e1_spkN1  c1_e2_spkN1 ... cN3_eN2_spkN1  timestamp_spkN1
 
 The timestamp is expressed in multiples of the sampling interval. For
 instance, for a 20kHz recording (50 microsecond sampling interval), a
@@ -70,21 +69,21 @@ Notice that the last line must end with a newline or carriage return.
 class KlustaKwikIO(BaseIO):
     """Reading and writing from KlustaKwik-format files."""
     # Class variables demonstrating capabilities of this IO
-    is_readable        = True
-    is_writable        = True
+    is_readable = True
+    is_writable = True
 
     # This IO can only manipulate objects relating to spike times
-    supported_objects  = [Block, SpikeTrain, Unit]
+    supported_objects = [Block, SpikeTrain, Unit]
 
     # Keep things simple by always returning a block
-    readable_objects    = [Block]
+    readable_objects = [Block]
 
     # And write a block
-    writeable_objects   = [Block]
+    writeable_objects = [Block]
 
     # Not sure what these do, if anything
-    has_header         = False
-    is_streameable     = False
+    has_header = False
+    is_streameable = False
 
     # GUI params
     read_params = {}
@@ -93,8 +92,8 @@ class KlustaKwikIO(BaseIO):
     write_params = {}
 
     # The IO name and the file extensions it uses
-    name               = 'KlustaKwik'
-    extensions          = ['fet', 'clu', 'res', 'spk']
+    name = 'KlustaKwik'
+    extensions = ['fet', 'clu', 'res', 'spk']
 
     # Operates on directories
     mode = 'file'
@@ -110,7 +109,7 @@ class KlustaKwikIO(BaseIO):
         if not HAVE_MLAB:
             raise MLAB_ERR
         BaseIO.__init__(self)
-        #self.filename = os.path.normpath(filename)
+        # self.filename = os.path.normpath(filename)
         self.filename, self.basename = os.path.split(os.path.abspath(filename))
         self.sampling_rate = float(sampling_rate)
 
@@ -121,9 +120,7 @@ class KlustaKwikIO(BaseIO):
         # initialize a helper object to parse filenames
         self._fp = FilenameParser(dirname=self.filename, basename=self.basename)
 
-    # The reading methods. The `lazy` and `cascade` parameters are imposed
-    # by neo.io API
-    def read_block(self, lazy=False, cascade=True):
+    def read_block(self, lazy=False):
         """Returns a Block containing spike information.
 
         There is no obvious way to infer the segment boundaries from
@@ -132,13 +129,15 @@ class KlustaKwikIO(BaseIO):
         boundaries, and then change this code to put the spikes in the right
         segments.
         """
+        assert not lazy, 'Do not support lazy'
+
         # Create block and segment to hold all the data
         block = Block()
         # Search data directory for KlustaKwik files.
         # If nothing found, return empty block
         self._fetfiles = self._fp.read_filenames('fet')
         self._clufiles = self._fp.read_filenames('clu')
-        if len(self._fetfiles) == 0 or not cascade:
+        if len(self._fetfiles) == 0:
             return block
 
         # Create a single segment to hold all of the data
@@ -170,69 +169,57 @@ class KlustaKwikIO(BaseIO):
             for unit_id in sorted(unique_unit_ids):
                 # Initialize the unit
                 u = Unit(name=('unit %d from group %d' % (unit_id, group)),
-                    index=unit_id, group=group)
+                         index=unit_id, group=group)
 
                 # Initialize a new SpikeTrain for the spikes from this unit
-                if lazy:
-                    st = SpikeTrain(
-                        times=[],
-                        units='sec', t_start=0.0,
-                        t_stop=spks.max() / self.sampling_rate,
-                        name=('unit %d from group %d' % (unit_id, group)))
-                    st.lazy_shape = len(spks[uids==unit_id])
-                else:
-                    st = SpikeTrain(
-                        times=spks[uids==unit_id] / self.sampling_rate,
-                        units='sec', t_start=0.0,
-                        t_stop=spks.max() / self.sampling_rate,
-                        name=('unit %d from group %d' % (unit_id, group)))
+                st = SpikeTrain(
+                    times=spks[uids == unit_id] / self.sampling_rate,
+                    units='sec', t_start=0.0,
+                    t_stop=spks.max() / self.sampling_rate,
+                    name=('unit %d from group %d' % (unit_id, group)))
                 st.annotations['cluster'] = unit_id
                 st.annotations['group'] = group
 
                 # put features in
-                if not lazy and len(features) != 0:
+                if len(features) != 0:
                     st.annotations['waveform_features'] = features
 
                 # Link
                 u.spiketrains.append(st)
                 seg.spiketrains.append(st)
 
-        create_many_to_one_relationship(block)
+        block.create_many_to_one_relationship()
         return block
 
     # Helper hidden functions for reading
     def _load_spike_times(self, fetfilename):
         """Reads and returns the spike times and features"""
-        f = file(fetfilename, 'r')
+        with open(fetfilename, mode='r') as f:
+            # Number of clustering features is integer on first line
+            nbFeatures = int(f.readline().strip())
 
-        # Number of clustering features is integer on first line
-        nbFeatures = int(f.readline().strip())
-
-        # Each subsequent line consists of nbFeatures values, followed by
-        # the spike time in samples.
-        names = ['fet%d' % n for n in xrange(nbFeatures)]
-        names.append('spike_time')
+            # Each subsequent line consists of nbFeatures values, followed by
+            # the spike time in samples.
+            names = ['fet%d' % n for n in range(nbFeatures)]
+            names.append('spike_time')
 
         # Load into recarray
-        data = mlab.csv2rec(f, names=names, skiprows=1, delimiter=' ')
-        f.close()
+        data = np.recfromtxt(fetfilename, names=names, skip_header=1, delimiter=' ')
 
         # get features
-        features = np.array([data['fet%d' % n] for n in xrange(nbFeatures)])
+        features = np.array([data['fet%d' % n] for n in range(nbFeatures)])
 
         # Return the spike_time column
         return data['spike_time'], features.transpose()
 
     def _load_unit_id(self, clufilename):
         """Reads and return the cluster ids as int32"""
-        f = file(clufilename, 'r')
+        with open(clufilename, mode='r') as f:
+            # Number of clusters on this tetrode is integer on first line
+            nbClusters = int(f.readline().strip())
 
-        # Number of clusters on this tetrode is integer on first line
-        nbClusters = int(f.readline().strip())
-
-        # Read each cluster name as a string
-        cluster_names = f.readlines()
-        f.close()
+            # Read each cluster name as a string
+            cluster_names = f.readlines()
 
         # Convert names to integers
         # I think the spec requires cluster names to be integers, but
@@ -252,7 +239,6 @@ class KlustaKwikIO(BaseIO):
 
         return cluster_ids
 
-
     # writing functions
     def write_block(self, block):
         """Write spike times and unit ids to disk.
@@ -334,8 +320,8 @@ class KlustaKwikIO(BaseIO):
                     fetfilehandle.write("%d\n" % n_features)
                 if n_features != all_features.shape[1]:
                     raise ValueError("inconsistent number of features: " +
-                        "supposed to be %d but I got %d" %\
-                        (n_features, all_features.shape[1]))
+                                     "supposed to be %d but I got %d" %
+                                     (n_features, all_features.shape[1]))
 
                 # Write features and time for each spike
                 for stt, features in zip(spike_times_in_samples, all_features):
@@ -393,9 +379,9 @@ class KlustaKwikIO(BaseIO):
     def _new_group(self, id_group, nbClusters):
         # generate filenames
         fetfilename = os.path.join(self.filename,
-            self.basename + ('.fet.%d' % id_group))
+                                   self.basename + ('.fet.%d' % id_group))
         clufilename = os.path.join(self.filename,
-            self.basename + ('.clu.%d' % id_group))
+                                   self.basename + ('.clu.%d' % id_group))
 
         # back up before overwriting
         if os.path.exists(fetfilename):
@@ -404,20 +390,23 @@ class KlustaKwikIO(BaseIO):
             shutil.copyfile(clufilename, clufilename + '~')
 
         # create file handles
-        self._fetfilehandles[id_group] = file(fetfilename, 'w')
-        self._clufilehandles[id_group] = file(clufilename, 'w')
+        self._fetfilehandles[id_group] = open(fetfilename, mode='w')
+        self._clufilehandles[id_group] = open(clufilename, mode='w')
 
         # write out first line
-        #self._fetfilehandles[id_group].write("0\n") # Number of features
+        # self._fetfilehandles[id_group].write("0\n") # Number of features
         self._clufilehandles[id_group].write("%d\n" % nbClusters)
 
     def _close_all_files(self):
-        for val in self._fetfilehandles.values(): val.close()
-        for val in self._clufilehandles.values(): val.close()
+        for val in self._fetfilehandles.values():
+            val.close()
+        for val in self._clufilehandles.values():
+            val.close()
 
 
 class FilenameParser:
     """Simple class to interpret user's requests into KlustaKwik filenames"""
+
     def __init__(self, dirname, basename=None):
         """Initialize a new parser for a directory containing files
 
@@ -454,7 +443,6 @@ class FilenameParser:
         """
         all_filenames = glob.glob(os.path.join(self.dirname, '*'))
 
-
         # Fill the dict with valid filenames
         d = {}
         for v in all_filenames:
@@ -475,6 +463,3 @@ class FilenameParser:
                     d[tetn] = v
 
         return d
-
-
-
