@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-Contains tests for neo.core
+The subdirectory coretest contains tests for neo.core
 
 The subdirectory iotest contains tests for neo.io
 """
