@@ -6,10 +6,7 @@ Tests of neo.io.baseio
 # needed for python 3 compatibility
 from __future__ import absolute_import, division
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
 
 from neo.core import objectlist
 from neo.io.baseio import BaseIO
@@ -20,11 +17,11 @@ class TestIOObjects(unittest.TestCase):
         reader = BaseIO()
         for ob in objectlist:
             if ob not in BaseIO.readable_objects:
-                meth = getattr(reader, 'read_'+ob.__name__.lower())
+                meth = getattr(reader, 'read_' + ob.__name__.lower())
                 self.assertRaises(AssertionError, meth, )
 
             if ob not in BaseIO.writeable_objects:
-                meth = getattr(reader, 'write_'+ob.__name__.lower())
+                meth = getattr(reader, 'write_' + ob.__name__.lower())
                 self.assertRaises(AssertionError, meth, ())
 
 
